@@ -1,24 +1,38 @@
 .plt.main <- 
 function(x, y, by, type, n.cat,
          col.fill, col.stroke, col.bg, col.grid,
-         shape.pts, col.area, col.box, 
+         shape.pts, col.area, col.box, col.trans, 
          cex.axis, col.axis, col.low, col.hi,
          xy.ticks, xlab, ylab, main, sub, cex,
-         value.labels, rotate.values, offset, kind, means,
-         fit.line, col.fit.line, bubble.size, bubble.counts,
+         value.labels, rotate.values, offset, style, means, stat,
+         fit.line, col.fit.line,
+         bubble.size, bubble.power, bubble.counts,
          ellipse, col.ellipse, fill.ellipse, 
-         diag, col.diag, lines.diag, quiet, want.labels=TRUE, ...)  {
-# want.labels set just for ttestPower, which provides its own labels
+         diag, col.diag, lines.diag, sort.y, segments.y, segments.x,
+         quiet, want.labels=TRUE, ...)  {
 
+# want.labels set just for ttestPower, which provides its own labels
   # both x and y are plotted, even if only a single variable
   # for a 1-D bubble plot of a single factor var, y.call was set to 0's
+  # numerical 1-D scatter plot done in .dp.main
   if (length(unique(y)) == 1) {
     bubble1 <- TRUE
-    if (kind == "default") kind <- "bubble"
+    if (style == "default") style <- "bubble"
   }
   else
     bubble1 <- FALSE
 
+  # sort y by x  (for Cleveland dot plot)
+  if (sort.y) {
+    ord <- order(x)
+    y <- factor(y, levels=y[ord])
+  }
+
+  # for a Cleveland dot plot, do not do a default bubble plot
+  unique.y <- ifelse(length(unique(y)) == length(y), TRUE, FALSE)
+  if (!is.factor(x) && is.factor(y) && unique.y)
+    if (n.cat == 10) n.cat <- 0
+
   do.ellipse <- ifelse(as.logical(ellipse[1]), TRUE, FALSE) 
 
   if (!is.null(value.labels)) value.labels <- gsub(" ", "\n", value.labels) 
@@ -36,16 +50,39 @@ function(x, y, by, type, n.cat,
     y <- as.integer(y)
   }
 
+  # see if trans is customized for this analysis
+  if (is.null(col.trans)) {  # no change, so no trans for Cleveland dp
+    if (is.null(x.lvl) && !is.null(y.lvl) && unique.y) { 
+      trans.pts <- 0 
+      col.fill <- .maketrans(col.fill, (1-trans.pts)*256)
+    }
+  }
+  else {  # trans has been changed from default, so change col.fill
+    trans.pts <- col.trans
+    col.fill <- .maketrans(col.fill, (1-trans.pts)*256)
+  }
+
+  num.cat.x <- ifelse(is.null(x.lvl) && .is.num.cat(x, n.cat), TRUE, FALSE)
+  cat.x <- ifelse (num.cat.x || !is.null(x.lvl), TRUE, FALSE)
+
+  if (!bubble1) {
+    num.cat.y <- ifelse(is.null(y.lvl) && .is.num.cat(y, n.cat), TRUE, FALSE)
+    cat.y <- ifelse (num.cat.y || !is.null(y.lvl), TRUE, FALSE)
+  }
+  else {
+    num.cat.y <- FALSE
+    cat.y <- FALSE
+  }
+
   nrows <- length(x)
-  pt.sz <- ifelse (.Platform$OS == "windows", 1, 0.8)
+  pt.sz <- ifelse (.Platform$OS == "windows", 1, 0.80)
   pt.size <- ifelse (is.null(cex), pt.sz, cex)
 
   if (is.null(col.fill)) col.fill <- "transparent"
   if (is.null(col.area)) col.area <- "transparent"
 
-  # get variable labels if exist plus axes labels
   if (want.labels) {
-    gl <- .getlabels(xlab, ylab, main, cex.lab=0.98)
+    gl <- .getlabels(xlab, ylab, main, cex.lab=0.85)
     x.name <- gl$xn; x.lbl <- gl$xl; x.lab <- gl$xb
     y.name <- gl$yn; y.lbl <- gl$yl; y.lab <- gl$yb
     main.lab <- gl$mb
@@ -58,30 +95,26 @@ function(x, y, by, type, n.cat,
     y.lab <- ylab
     main.lab <- main
     sub.lab <- sub
-    cex.lab <- 0.98
+    cex.lab <- 0.85
   }
 
   if (is.null(type)) {  # if x is sorted with equal intervals, plot a line chart
     if (sum(is.na(x)) > 0)
-      equal.int <- FALSE  # missing data in x present
+      eq.int <- FALSE  # missing data in x present
     else {
-      diff.x <- diff(x)
+      eq.int <- TRUE
+      d.x <- diff(x)
       for (i in 2:(length(x)-1)) 
-        if ((abs(diff.x[i-1] - diff.x[i]) > 0.0000000001)) 
-          equal.int <- FALSE
-        else
-          equal.int <- TRUE
-      rm(diff.x)
+        if ((abs(d.x[i-1] - d.x[i]) > 0.0000000001)) eq.int <- FALSE
+      rm(d.x)
     }  # also no y missing
-    type <- ifelse (!is.unsorted(x) && equal.int && sum(is.na(y))==0, "l", "p") 
+
+    type <- ifelse (!is.unsorted(x) && eq.int && sum(is.na(y))==0, "l", "p") 
   }
 
-  # bubble plot for small number of unique values
-  if (kind == "default")  # set default
-    if (length(unique(x))<n.cat && length(unique(y))<n.cat)
-      kind <- "bubble"
-    else
-      kind <- "regular"
+  # set bubble plot for small number of unique values of x and y
+  if (style == "default")  # set default
+    style <- ifelse (cat.x && cat.y, "bubble", "regular")
   
   digits.d <- .max.dd(y) + 1
   options(digits.d=digits.d)
@@ -90,6 +123,55 @@ function(x, y, by, type, n.cat,
   # -------------------------
   # plot
   # -------------------------
+  x.val <- NULL
+  y.val <- y.lvl  # if not reset to x value labels
+  max.lbl.y <- NULL
+  if (!is.null(value.labels)) { 
+    x.val <- value.labels
+    if (length(unique(y)) > 1) {  # see if set y axis values to those of x
+      if (length(unique(na.omit(x))) == length(unique(na.omit(y)))) {
+        if (all(sort(unique(x)) == sort(unique(y)))) {
+          y.val <- value.labels
+          v <- unlist(strsplit(value.labels, "\n", fixed=TRUE))
+          max.lbl.y <- max(nchar(v))
+        }
+      }
+    }
+  }
+  else {
+    x.val <- x.lvl  # x.val is NULL if x is numeric, ignored
+    y.val <- y.lvl  # y.val ignored if y is numeric 
+  }
+
+  plot.new()  # activate for strwidth
+
+  if (!is.null(y.val)) {
+    max.width <- 0
+    for (i in (1:length(y.val))) {
+      li <- ifelse(!is.na(y.val[i]), strwidth(y.val[i], units="inches"), 0)
+      if (li > max.width)
+        max.width <- strwidth(y.val[i], units="inches")
+    }
+  }
+  else 
+    max.width <- strwidth(as.character(max(pretty(y))), units="inches")
+
+  lm <- max(max.width + 0.3, 0.67)
+  if (!is.null(y.lab)) {
+    if (!nzchar(y.lab)[1]) lm <- lm - 0.3
+    if (grepl("\n", y.lab[1], fixed=TRUE)) lm <- lm + .15
+  }
+  else
+    lm <- lm - 0.3
+
+  rm <- ifelse (is.null(by), 0.25, 0.95)
+  tm <- ifelse (is.null(main), 0.25, 0.75)
+  bm <- 0.75
+
+  orig.params <- par(no.readonly=TRUE)
+  on.exit(par(orig.params))
+  par(mai=c(bm, lm, tm, rm))
+
 
   # -----------------------
   # setup coordinate system with plot and type="n"
@@ -97,24 +179,39 @@ function(x, y, by, type, n.cat,
   
   if (!do.ellipse) {
 
-    if (kind == "regular") {
-
-      if (!is.null(by)) {  # make room for legend in right margin
-        orig.params <- par(no.readonly=TRUE)
-        on.exit(par(orig.params))
-        par(omi=c(0,0,0,0.6))
-      }
+    if (style %in% c("regular", "off")) {
 
       if (!lines.diag) {
-        if (length(unique(na.omit(x))) > 4)
-          plot(x,y, type="n", axes=FALSE, ann=FALSE, ...)
-        else {  # create a buffer on ends of x-axis 
-          mn.x <- min(x, na.rm=TRUE) - .5
-          mx.x <- max(x, na.rm=TRUE) + .5
-          plot(x,y, type="n", axes=FALSE, ann=FALSE,
-                                xlim=c(mn.x,mx.x), ...)
+        unq.x <- length(unique(na.omit(x)))
+        unq.y <- length(unique(na.omit(y)))
+        if (unq.x > 5  &&  unq.y > 5) {
+          if (stat != "count")
+            plot(x,y, type="n", axes=FALSE, ann=FALSE, ...)
+          else {  # plot counts
+            mx.y <- max(pretty(y))
+            plot(x,y, type="n", axes=FALSE, ann=FALSE, ylim=c(0, mx.y), ...)
+          }
         }
-      }
+        else {  # create a buffer on ends of an axis 
+
+          mn.x <- min(x, na.rm=TRUE)
+          mx.x <- max(x, na.rm=TRUE)
+          mn.y <- min(y, na.rm=TRUE)
+          mx.y <- max(y, na.rm=TRUE)
+          if (unq.x <= 5) {
+            buf.x <- 0.74 - (0.12 * unq.x)
+            mn.x <- mn.x - buf.x
+            mx.x <- mx.x + buf.x
+          }
+          if (unq.y <= 5) {
+            buf.y <- 0.74 - (0.12 * unq.y)
+            mn.y <- mn.y - buf.y
+            mx.y <- mx.y + buf.y
+          }
+          plot(x,y, type="n", axes=FALSE, ann=FALSE,
+               xlim=c(mn.x,mx.x), ylim=c(mn.y,mx.y), ...)
+        }
+      }  # no diag
       else {  # need same x,y limits on both axes for lines.diag
         nums <- pretty(c(min(x,y, na.rm=TRUE), max(x,y, na.rm=TRUE)))
         l1 <- nums[1]
@@ -124,7 +221,7 @@ function(x, y, by, type, n.cat,
       }
     }
 
-    else if (kind %in% c("bubble", "sunflower")) {
+    else if (style %in% c("bubble", "sunflower", "off")) {
 
       # get start and end values for each axis
       x.start=min(x, na.rm=TRUE)  # for bubble plot
@@ -132,6 +229,24 @@ function(x, y, by, type, n.cat,
       y.start=min(y, na.rm=TRUE) 
       y.end=max(y, na.rm=TRUE)
 
+      if (!is.null(x.lvl)) {  # categorical - factor
+        x.start <- .5
+        x.end <- length(x.lvl) + .5
+      }
+      else if (num.cat.x) {  # categorical - numerical
+        x.start <- x.start-.5
+        x.end <- x.end+.5
+      }
+
+      if (!is.null(y.lvl)) {
+        y.start <- .5
+        y.end <- length(y.lvl) + .5
+      }
+      else if (num.cat.y) {
+        y.start <- y.start-.5
+        y.end <- y.end+.5
+      }
+
       dots <- list(...)  # if xlim or ylim present, use these values
       if (length(dots) > 0) {
         for (i in 1:length(dots)) {
@@ -146,27 +261,22 @@ function(x, y, by, type, n.cat,
         }
       }
 
-      x.lo <- x.start-.5; x.hi <- x.end+.5
-      y.lo <- y.start-.5; y.hi <- y.end+.5
-
       plot(x,y, type="n", axes=FALSE, ann=FALSE, 
-           xlim=c(x.lo,x.hi), ylim=c(y.lo,y.hi))
+           xlim=c(x.start,x.end), ylim=c(y.start,y.end))
     }
 
-    else {
-      cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "This type of plot not recognized: ", kind, "\n\n")
-    }
   }
 
-  else {  # calculate ellipse(s), set plot with sufficient room
+  else {  # set plot with sufficient room for ellipse and data
     cxy <- cor(x,y, use="complete.obs")
     s.x <- sd(x, na.rm=TRUE); s.y <- sd(y, na.rm=TRUE)
     m.x <- mean(x, na.rm=TRUE); m.y <- mean(y, na.rm=TRUE)
     lvl <- max(ellipse)
-    lvl <- ifelse(lvl > 0.95, lvl, 0.95)  # set plot region for at least 0.95
-    e <- ellipse(cxy, scale=c(s.x, s.y), centre=c(m.x, m.y), level=lvl)
-    plot(e, type="n", axes=FALSE, ann=FALSE, main=main.lab, ...)
+    f <- ellipse(cxy, scale=c(s.x, s.y), centre=c(m.x, m.y), level=lvl)
+    f <- rbind(f, c(min(x, na.rm=TRUE), min(y, na.rm=TRUE)))
+    f <- rbind(f, c(max(x, na.rm=TRUE), max(y, na.rm=TRUE)))
+    plot(f, type="n", axes=FALSE, ann=FALSE, main=main.lab, ...)
+    rm(f)
   }
 
 
@@ -175,28 +285,24 @@ function(x, y, by, type, n.cat,
   # x.lvl and y.lvl are NULL unless x and y are factors
 
   #axis, axis ticks, value labels
-  x.val <- NULL; y.val <- NULL
-  if (!is.null(value.labels)) { 
-    if (length(unique(y)) > 1)
-      if (length(unique(x)) == length(unique(y)))  # see if set y axis values to those of x
-        if (all(sort(unique(x)) == sort(unique(y)))) y.val <- value.labels
-    x.val <- value.labels
-  }
-  else {
-    x.val <- x.lvl  # x.val is NULL if x is numeric
-    y.val <- y.lvl  # y.val is NULL if y is numeric 
-  }
 
-  if (!is.null(x.lvl) || length(unique(x)) <= n.cat) 
-      axT1 <- sort(unique(x))  # just mark the category values
+  if (cat.x) {
+    if (!is.null(x.lvl)) axT1 <- 1:length(x.lvl)   # mark category values
+    if (num.cat.x) axT1 <- sort(unique(x))
+    #if (num.cat.x) axT1 <- axTicks(1)
+  }
   else
     axT1 <- axTicks(1)  # else numeric, so all the ticks
-  if (!is.null(y.lvl) || length(unique(y)) <= n.cat) 
-    axT2 <- sort(unique(y)) 
+
+  if (cat.y) { 
+    if (!is.null(y.lvl)) axT2 <- 1:length(y.lvl)
+    if (num.cat.y) axT2 <- sort(unique(y))
+    #if (num.cat.y) axT2 <- axTicks(2)
+  }
   else
     axT2 <- axTicks(2) 
 
-  if (xy.ticks)
+  if (xy.ticks) {
     if (!bubble1)
       .axes(x.val, y.val, axT1, axT2,
             par("usr")[1], par("usr")[3], cex.axis, col.axis,
@@ -205,26 +311,26 @@ function(x, y, by, type, n.cat,
       .axes(x.val, NULL, axT1, NULL,
             par("usr")[1], par("usr")[3], cex.axis, col.axis, 
             rotate.values, offset=offset, ...)
+  }
        
   # axis labels 
-  if (!is.null(y.lvl) || !is.null(value.labels)) {
-    if (!is.null(value.labels)) {
-      v <- unlist(strsplit(value.labels, "\n", fixed=TRUE))
-      max.lbl <- max(nchar(v))
+  if (is.null(max.lbl.y)) {  # could be set earlier when x.val = y.val
+    if (!is.null(y.lvl)) {
+      max.lbl.y <- max(nchar(y.lvl))
     }
     else
-      max.lbl <- max(nchar(y.lvl))
-  }
-  else
-    max.lbl <- max(nchar(axTicks(2)))
-  if (bubble1) {
-    y.lab <- ""
-    max.lbl <- 0
+      max.lbl.y <- max(nchar(axTicks(2)))
   }
 
-  .axlabs(x.lab, y.lab, main.lab, sub.lab, max.lbl, 
+  if (bubble1) {
+    y.lab <- ""
+    max.lbl.y <- 0
+  }
+
+  .axlabs(x.lab, y.lab, main.lab, sub.lab, max.lbl.y, 
           xy.ticks, offset=offset, cex.lab=cex.lab, ...) 
 
+
   # color plotting area
   usr <- par("usr")
   rect(usr[1], usr[3], usr[2], usr[4], col=col.bg, border=col.box)
@@ -238,11 +344,11 @@ function(x, y, by, type, n.cat,
 
   # grid lines
   if (!bubble1) {
-    abline(v=axT1, col=col.grid, lwd=.75)
-    abline(h=axT2, col=col.grid, lwd=.75)
+    abline(v=axT1, col=col.grid, lwd=.5)
+    abline(h=axT2, col=col.grid, lwd=.5)
   }
   else
-    abline(v=axTicks(1), col=col.grid, lwd=.75)  # bubbles only
+    abline(v=axT1, col=col.grid, lwd=.75)  # bubbles only
 
   # fill area under curve
   col.border <- ifelse (type != "p", col.stroke, "transparent")
@@ -251,27 +357,34 @@ function(x, y, by, type, n.cat,
             col=col.area, border=col.border)
 
   # plot the values
-  if (kind == "regular") {  # plot lines and/or points
+  if (style %in% c("regular", "off")) {  # plot lines and/or points
     if (type == "l" | type == "b")
       lines(as.numeric(x),y, col=col.stroke, ...)
 
     if (type == "p" | type == "b") {
 
       if (is.null(by)) { 
+            
+        if (style != "off") {
+          points(x,y, pch=shape.pts, col=col.stroke, bg=col.fill, cex=pt.size, ...)
 
-        trans.pts <- getOption("trans.fill.pt")  # plot points
-        clr.trn <- .maketrans(col.fill, (1-trans.pts)*256)
-        points(x,y, pch=shape.pts, col=col.stroke,
-            bg=clr.trn, cex=pt.size, ...)
+          if (segments.y)
+            segments(x0=min(pretty(x)), y0=y, x1=x, y1=y, lty=1, lwd=.75,
+                     col=col.stroke)
+          if (segments.x)
+            segments(y0=min(pretty(y)), x0=x, y1=y, x1=x, lty=1, lwd=.75,
+                     col=col.stroke)
+        }
 
         if (!is.null(x.lvl) && means) {  # plot means
-          for (i in (1:length(x.lvl))) {
-            m.lvl <- mean(y[x==i], na.rm=TRUE)
-            abline(h=m.lvl, col="gray50")
-            bck.g <- ifelse(getOption("colors")!="gray", "gray50", "gray30")
-            if (grepl(".black", getOption("colors"), fixed=TRUE)) bck.g <- "gray85"
-            points(i, m.lvl, pch=23, bg=bck.g)
-          }
+          m.lvl <- numeric(length = 0)
+          for (i in (1:length(x.lvl))) 
+            m.lvl[i] <- mean(y[x==i], na.rm=TRUE)
+          pch.avg <- ifelse(getOption("colors")!="gray", 21, 23)
+          bck.g <- ifelse(getOption("colors")!="gray", "gray15", "gray30")
+          if (grepl(".black", getOption("colors"), fixed=TRUE)) bck.g <- "gray85"
+          abline(h=m.lvl, col="gray50", lwd=.5)
+          points(m.lvl, pch=pch.avg, bg=bck.g)
         }
       }
 
@@ -291,8 +404,8 @@ function(x, y, by, type, n.cat,
         else
           shp <- shape.pts
         shape.dft <- c(21,23,22,24,25,7:14)  # shape defaults
-        if (length(col.stroke)==1 && length(shape.pts)==1)  # both shape and color default
-          for (i in 1:n.levels) shp[i] <- shape.dft[i]  # fill with default shapes
+        if (length(col.stroke)==1 && length(shape.pts)==1)  # shape, color 
+          for (i in 1:n.levels) shp[i] <- shape.dft[i]  # fill is default shapes
 
         trans.pts <- getOption("trans.fill.pt")
         for (i in 1:n.levels) {
@@ -306,31 +419,16 @@ function(x, y, by, type, n.cat,
       if (length(col.stroke) > 1) clr.tr <- clr
       .plt.legend(levels(by), col.stroke, clr, clr.tr, shp, trans.pts, col.bg, usr)
 
-      }  # end by group
+      }  # end by
 
     }  # type == "p" | type == "b"
-  }  # kind = "regular"
+  }  # style = "regular"
 
 
-  else if (kind %in% c("bubble", "sunflower")) {
+  else if (style %in% c("bubble", "sunflower")) {
 
     mytbl <- table(x, y)  # get the counts
 
-    # melt the table to a data frame
-    k <- 0
-    xx <- integer(length=0)
-    yy <- integer(length=0)
-    count <- integer(length=0)
-    for (i in 1:nrow(mytbl)) {
-      for (j in 1:ncol(mytbl)) {
-        k <- k + 1
-        count[k] <- mytbl[i,j]
-        xx[k] <- as.integer(rownames(mytbl)[i])
-        yy[k] <- as.integer(colnames(mytbl)[j])
-      }
-    }
-    cords <- data.frame(xx, yy, count)
-
     # colors
     if (is.null(col.low) ||  is.null(col.hi))
       clr <- col.fill
@@ -339,22 +437,41 @@ function(x, y, by, type, n.cat,
       clr <- color.palette(nrow(mytbl))
     }
 
-    c <- cords$count  # 0 plots to a single pixel, so remove
-    for (i in 1:length(c)) if (c[i]==0) c[i] <- NA
+    # melt the table to a data frame
+    k <- 0
+    xx <- integer(length=0)
+    yy <- integer(length=0)
+    count <- integer(length=0)
+    for (i in 1:nrow(mytbl)) {
+      for (j in 1:ncol(mytbl)) {
+        if (mytbl[i,j] != 0) {  # 0 plots to a single pixel, so remove
+          k <- k + 1
+          count[k] <- mytbl[i,j]
+          xx[k] <- as.numeric(rownames(mytbl)[i])  # rownames are factors
+          yy[k] <- as.numeric(colnames(mytbl)[j])
+        }
+      }
+    }
+    cords <- data.frame(xx, yy, count)
 
-    if (kind == "bubble")
-      symbols(cords$xx, cords$yy, circles=c, bg=clr, 
-            fg=col.stroke, inches=bubble.size, add=TRUE, ...)
+    c <- cords$count
+    if (style == "bubble")
+      symbols(as.numeric(cords$xx), as.numeric(cords$yy),
+            circles=c**bubble.power, inches=bubble.size,
+            bg=clr, fg=col.stroke, add=TRUE, ...)
 
-    else if (kind == "sunflower") {
-      sunflowerplot(cords$xx, cords$yy, number=cords$count, 
+    else if (style == "sunflower") {
+      sunflowerplot(cords$xx, cords$yy, number=c, 
         seg.col=col.stroke, col=col.fill, cex.axis=cex.axis, col.axis=col.axis,
-        xlab=x.lab, ylab=y.lab, xlim=c(x.lo,x.hi), ylim=c(x.lo,x.hi), add=TRUE)
+        xlab=x.lab, ylab=y.lab,
+        xlim=c(x.start,x.end), ylim=c(x.start,x.end), add=TRUE)
   }
 
-    if (bubble.counts  &&  kind == "bubble") { 
-      max.c <- max(c, na.rm=TRUE)  # do not display count if bubble is too small
-      min.bubble <- 0.25 * max.c
+    if (bubble.counts  &&  style == "bubble") { 
+      max.c <- max(c, na.rm=TRUE)  # bubble is too small for count
+      #min.bubble <- 0.25 * max.c  # radius, bubble.power=1
+      #min.bubble <- 0.10 * max.c  # bubble.power=.6
+      min.bubble <- (bubble.power/9) * max.c
       for (i in 1:length(c))
         if (!is.na(c[i])) if (c[i] <= min.bubble) c[i] <- NA
       text(cords$xx, cords$yy, c, cex=.7)
@@ -420,21 +537,8 @@ function(x, y, by, type, n.cat,
 
 
   # text output
-  # correlation
   if (!quiet) {
 
-    nu <- length(unique(na.omit(x)))
-    num.cat <- ifelse(is.null(x.lvl) && nu <= n.cat, TRUE, FALSE)
-    cat.x <- ifelse (num.cat || !is.null(x.lvl), TRUE, FALSE)
-
-    if (!bubble1) {
-      nu <- length(unique(na.omit(y)))
-      num.cat <- ifelse(is.null(y.lvl) && nu <= n.cat, TRUE, FALSE)
-      cat.y <- ifelse (num.cat || !is.null(y.lvl), TRUE, FALSE)
-    }
-    else
-      cat.y <- FALSE
-
     # traditional two-var numeric var scatter plot
     if (!cat.x  &&  !cat.y  &&  type == "p") {
       if (do.ellipse) { # ellipse option removes any missing data
@@ -460,10 +564,10 @@ function(x, y, by, type, n.cat,
     }
 
     # categorical x var, numeric y var
-    else if (cat.x && !cat.y) {
+    else if (cat.x && !cat.y && stat=="") {
 
       if (!is.null(x.lvl))
-        x.by <- factor(x, labels=x.lvl)  # convert back to a factor
+        x.by <- factor(x, levels=1:length(x.lvl), labels=x.lvl)  # convert back to a factor
       else
         x.by <- x
 
@@ -496,19 +600,36 @@ function(x, y, by, type, n.cat,
       }
     }
 
+    else if (!cat.x && cat.y && stat == "") {  # Cleveland dot plot
+      if (!is.null(y.lvl))
+        y.by <- factor(y, levels=1:length(y.lvl), labels=y.lvl)  # convert back to a factor
+      else
+        y.by <- y
+
+        stats <- .ss.numeric(x, digits.d=digits.d, brief=TRUE)
+        txout <- stats$tx
+        class(txout) <- "out_piece"
+
+        output <- list(out_txt=txout)
+        class(output) <- "out_all"
+        print(output)
+    }
+
     # categorical x and y vars
     else if (cat.x  &&  cat.y) {
       if (!is.null(x.lvl))
-        x.fac <- factor(x, labels=x.lvl)
+        x.fac <- factor(x, levels=1:length(x.lvl), labels=x.lvl)
       else
         x.fac <- x
       if (!is.null(y.lvl))
-        y.fac <- factor(y, labels=y.lvl)
+        y.fac <- factor(y, levels=1:length(y.lvl), labels=y.lvl)
       else
         y.fac <- y
+
       stats <- .ss.factor(x.fac, y.fac, brief=TRUE, digits.d=NULL,
                           x.name, y.name, x.lbl, y.lbl)
 
+
       txttl <- stats$txttl
       txfrq <- stats$txfrq
       txXV <- stats$txXV
@@ -523,5 +644,6 @@ function(x, y, by, type, n.cat,
   cat("\n")
   }       
 
+
 }  # end plt.main
 
