@@ -346,9 +346,10 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
        col.stroke=getOption("col.stroke.pt"), 
        col.fill=getOption("col.fill.bar"), shape.pts=21,
        col.grid=getOption("col.grid"), col.bg=getOption("col.bg"),
-       cex.axis=0.85, col.axis="gray30", xy.ticks=TRUE,
-       line.width=1.1, xlab=NULL, ylab=paste(Ynm,": ",X1nm, sep=""),
-       main=plt.title[plt.i],
+       cex.axis=0.75, col.axis="gray30", rotate.values=0, offset=.5,
+       xy.ticks=TRUE, line.width=1.1,
+       xlab=NULL, ylab=paste(Ynm,": ",X1nm, sep=""),
+       main=plt.title[plt.i], sub=NULL,
        cex=NULL, time.start=NULL, time.by=NULL, time.reverse=FALSE,
        center.line="default", quiet=TRUE)
 
@@ -370,9 +371,10 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
        col.stroke=getOption("col.stroke.pt"), 
        col.fill=getOption("col.fill.bar"), shape.pts=21,
        col.grid=getOption("col.grid"), col.bg=getOption("col.bg"),
-       cex.axis=0.85, col.axis="gray30", xy.ticks=TRUE,
-       line.width=1.1, xlab=NULL, ylab=paste(Ynm,": ",X2nm, sep=""),
-       main=plt.title[plt.i],
+       cex.axis=0.85, col.axis="gray30", rotate.values=0, offset=.5,
+       xy.ticks=TRUE, line.width=1.1,
+       xlab=NULL, ylab=paste(Ynm,": ",X2nm, sep=""),
+       main=plt.title[plt.i], sub=NULL,
        cex=NULL, time.start=NULL, time.by=NULL, time.reverse=FALSE,
 
        center.line="default", quiet=TRUE)
